|Build Status| |Coverage Status|

.. |Build Status| image:: https://travis-ci.org/raratiru/thepysec.svg?branch=master
   :alt: Build Status
   :target: https://travis-ci.org/raratiru/thepysec
.. |Coverage Status| image:: https://coveralls.io/repos/github/raratiru/thepysec/badge.svg?branch=master&service=github
   :alt: Coverage Status
   :target: https://coveralls.io/github/raratiru/thepysec?branch=master

A collection of tools that support a busy project.

John
----

John is the Battler. He will serve the necessary files needed to run thepysec.


Lia
---

Lia is here to take a detailed look at your strings.
